{ nix-config, config, pkgs, ... }:
{

  imports = with nix-config.homeModules; [
    shell-conf # shell, shell utils, cli tools, libs, tui's
    git-conf
  ];

  home = {
    packages = with pkgs; [
      btop
    ];

    username = "emenel";
    homeDirectory = "/home/emenel";

    sessionVariables = {
      NH_FLAKE = "\${HOME}/nixos-config";
    };

    sessionPath = [
      "/home/emenel/.local/bin"
      "/home/emenel/.local/share"
      "/home/emenel/.nix-profile/lib"
      "/etc/profiles/per-user/emenel/bin/"
      "/home/emenel/.local/state/nix/profiles/home-manager/home-path/bin/"
    ];

    stateVersion = "25.05";
  };

  sops = {
    age.keyFile = "/home/media/.config/sops/age/keys.txt"; # must have no password!
    defaultSopsFile = ../emenel/secrets.yaml;
  };

  programs = {
    home-manager.enable = true;
    password-store.enable = true;
  };

  systemd.user = {
    enable = true;
    startServices = "sd-switch"; # auto reload services when home is rebuilt
  };

  #custom script executables
  home.file.".local/bin" = {
    source = ../emenel/dotfiles/dot_local/bin;
    recursive = true;
  };
}
